@@ -1,28 +1,27 @@
 
 /*
- *  $Id: functions.c,v 4.6 2006/01/24 23:22:17 bkorb Exp $
+ *  $Id: functions.c,v 4.15 2007/07/04 20:51:12 bkorb Exp $
+ *
+ *  Time-stamp:        "2007-07-04 11:26:40 bkorb"
+ *  Last Committed:    $Date: 2007/07/04 20:51:12 $
  *
  *  This module implements text functions.
- */
-
-/*
- *  AutoGen copyright 1992-2005 Bruce Korb
  *
- *  AutoGen is free software.
- *  You may redistribute it and/or modify it under the terms of the
- *  GNU General Public License, as published by the Free Software
- *  Foundation; either version 2, or (at your option) any later version.
+ *  This file is part of AutoGen.
+ *  AutoGen copyright (c) 1992-2007 by Bruce Korb - all rights reserved
  *
- *  AutoGen is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ * AutoGen is free software: you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published by the
+ * Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with AutoGen.  See the file "COPYING".  If not,
- *  write to:  The Free Software Foundation, Inc.,
- *             51 Franklin Street, Fifth Floor,
- *             Boston, MA  02110-1301, USA.
+ * AutoGen is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ * See the GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along
+ * with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 tSCC zCantInc[] = "cannot include file";
@@ -50,11 +49,11 @@ mFunc_Include( tTemplate* pT, tMacro* pMac )
 {
     tTemplate* pNewTpl;
     ag_bool    needFree;
-    char*      pzFile = evalExpression( &needFree );
+    tCC*       pzFile = evalExpression( &needFree );
     tMacro*    pM;
 
     if (*pzFile != NUL) {
-        pNewTpl = loadTemplate( pzFile );
+        pNewTpl = loadTemplate(pzFile, pT->pzTplFile);
 
         /*
          *  Strip off trailing white space from included templates
@@ -69,7 +68,7 @@ mFunc_Include( tTemplate* pT, tMacro* pMac )
              *  IF there is no text left, remove the macro entirely
              */
             if (pz == pzE)
-                 --(pNewTpl->macroCt);
+                 pNewTpl->macroCt--;
             else *pzE = NUL;
         }
 
@@ -246,13 +245,13 @@ tMacro*
 mLoad_Unknown( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
 {
     char*          pzCopy = pT->pNext;
-    const char*    pzSrc;
+    char const*    pzSrc;
     size_t         srcLen = (size_t)pMac->res;         /* macro len  */
 
     if (srcLen <= 0)
         goto return_emtpy_expression;
 
-    pzSrc = (const char*)pMac->ozText; /* macro text */
+    pzSrc = (char const*)pMac->ozText; /* macro text */
 
     switch (*pzSrc) {
     case ';':
@@ -296,7 +295,7 @@ mLoad_Unknown( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
         /*
          *  Now copy over the full canonical name.  Check for errors.
          */
-        remLen = canonicalizeName( pzCopy, pzSrc, srcLen );
+        remLen = canonicalizeName( pzCopy, pzSrc, (int)srcLen );
         if (remLen > srcLen)
             AG_ABEND_IN( pT, pMac, "Invalid definition name" );
 
@@ -348,7 +347,7 @@ mLoad_Bogus( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
     tSCC zUnk[] =
         "Unknown macro or invalid context in %s line %d:\n\t%s%s";
 
-    tCC* pzSrc = (const char*)pMac->ozText; /* macro text */
+    tCC* pzSrc = (char const*)pMac->ozText; /* macro text */
     tCC* pzMac;
 
     char z[ 64 ];
@@ -356,12 +355,12 @@ mLoad_Bogus( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
     if (pzSrc != NULL) {
         z[0] = ':';
         z[1] = z[2] = ' ';
-        strncpy( z+3, pzSrc, 60 );
+        strncpy( z+3, pzSrc, (size_t)60 );
         z[63] = NUL;
         pzSrc = z;
     }
     else
-        pzSrc = "";
+        pzSrc = zNil;
 
     {
         int ix = pMac->funcCode;
@@ -381,7 +380,6 @@ mLoad_Bogus( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
- * tab-width: 4
  * indent-tabs-mode: nil
  * End:
  * end of agen5/functions.c */
