@@ -1,61 +1,38 @@
 
 /*
- *  $Id: enumeration.c,v 4.14 2006/11/27 01:52:23 bkorb Exp $
- * Time-stamp:      "2006-11-26 14:32:33 bkorb"
+ *  $Id: enumeration.c,v 4.19 2007/07/04 21:36:37 bkorb Exp $
+ * Time-stamp:      "2007-07-04 11:33:42 bkorb"
  *
  *   Automated Options Paged Usage module.
  *
  *  This routine will run run-on options through a pager so the
  *  user may examine, print or edit them at their leisure.
- */
-
-/*
- *  Automated Options copyright 1992-2006 Bruce Korb
  *
- *  Automated Options is free software.
- *  You may redistribute it and/or modify it under the terms of the
- *  GNU General Public License, as published by the Free Software
- *  Foundation; either version 2, or (at your option) any later version.
+ *  This file is part of AutoOpts, a companion to AutoGen.
+ *  AutoOpts is free software.
+ *  AutoOpts is copyright (c) 1992-2007 by Bruce Korb - all rights reserved
  *
- *  Automated Options is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  AutoOpts is available under any one of two licenses.  The license
+ *  in use must be one of these two and the choice is under the control
+ *  of the user of the license.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with Automated Options.  See the file "COPYING".  If not,
- *  write to:  The Free Software Foundation, Inc.,
- *             51 Franklin Street, Fifth Floor,
- *             Boston, MA  02110-1301, USA.
+ *   The GNU Lesser General Public License, version 3 or later
+ *      See the files "COPYING.lgplv3" and "COPYING.gplv3"
  *
- * As a special exception, Bruce Korb gives permission for additional
- * uses of the text contained in his release of AutoOpts.
+ *   The Modified Berkeley Software Distribution License
+ *      See the file "COPYING.mbsd"
  *
- * The exception is that, if you link the AutoOpts library with other
- * files to produce an executable, this does not by itself cause the
- * resulting executable to be covered by the GNU General Public License.
- * Your use of that executable is in no way restricted on account of
- * linking the AutoOpts library code into it.
+ *  These files have the following md5sums:
  *
- * This exception does not however invalidate any other reasons why
- * the executable file might be covered by the GNU General Public License.
- *
- * This exception applies only to the code released by Bruce Korb under
- * the name AutoOpts.  If you copy code from other sources under the
- * General Public License into a copy of AutoOpts, as the General Public
- * License permits, the exception does not apply to the code that you add
- * in this way.  To avoid misleading anyone as to the status of such
- * modified files, you must delete this exception notice from them.
- *
- * If you write modifications of your own for AutoOpts, it is your choice
- * whether to permit this exception to apply to your modifications.
- * If you do not wish that, delete this exception notice.
+ *  239588c55c22c60ffe159946a760a33e pkg/libopts/COPYING.gplv3
+ *  fa82ca978890795162346e661b47161a pkg/libopts/COPYING.lgplv3
+ *  66a5cedaf62c4b2637025f049f9b826f pkg/libopts/COPYING.mbsd
  */
 
 tSCC*  pz_enum_err_fmt;
 
 /* = = = START-STATIC-FORWARD = = = */
-/* static forward declarations maintained by :mkfwd */
+/* static forward declarations maintained by mk-fwd */
 static void
 enumError(
     tOptions*     pOpts,
@@ -266,6 +243,8 @@ optionEnumerationVal(
     tCC * const * paz_names,
     unsigned int  name_ct )
 {
+    uintptr_t res = 0UL;
+
     /*
      *  IF the program option descriptor pointer is invalid,
      *  then it is some sort of special request.
@@ -276,7 +255,7 @@ optionEnumerationVal(
          *  print the list of enumeration names.
          */
         enumError( pOpts, pOD, paz_names, (int)name_ct );
-        return 0UL;
+        break;
 
     case 1UL:
     {
@@ -288,8 +267,10 @@ optionEnumerationVal(
             printf( "INVALID-%d", ix );
         else
             fputs( paz_names[ ix ], stdout );
-        return 0UL;
+
+        break;
     }
+
     case 2UL:
     {
         tSCC zInval[] = "*INVALID*";
@@ -300,13 +281,21 @@ optionEnumerationVal(
         if (ix >= name_ct)
             return (uintptr_t)zInval;
 
-        return (uintptr_t)paz_names[ ix ];
-    }
-    default:
+        res = (uintptr_t)paz_names[ ix ];
         break;
     }
 
-    return findName( pOD->optArg.argString, pOpts, pOD, paz_names, name_ct );
+    default:
+        res = findName( pOD->optArg.argString, pOpts, pOD, paz_names, name_ct );
+
+        if (pOD->fOptState & OPTST_ALLOC_ARG) {
+            AGFREE(pOD->optArg.argString);
+            pOD->fOptState &= ~OPTST_ALLOC_ARG;
+            pOD->optArg.argString = NULL;
+        }
+    }
+
+    return res;
 }
 
 
@@ -383,7 +372,8 @@ optionSetMembers(
             bits >>= 1;
         }
 
-        pOD->optArg.argString = pz = malloc( len );
+        pOD->optArg.argString = pz = AGALOC( len, "enum name" );
+
         /*
          *  Start by clearing all the bits.  We want to turn off any defaults
          *  because we will be restoring to current state, not adding to
