@@ -1,7 +1,7 @@
 
 /*
- *  $Id: nested.c,v 4.16 2007/07/04 21:36:37 bkorb Exp $
- *  Time-stamp:      "2007-07-04 10:22:17 bkorb"
+ *  $Id: nested.c,v 4.17 2007/08/04 06:17:45 bkorb Exp $
+ *  Time-stamp:      "2007-08-03 23:03:45 bkorb"
  *
  *   Automated Options Nested Values module.
  *
@@ -27,7 +27,7 @@
  */
 
 /* = = = START-STATIC-FORWARD = = = */
-/* static forward declarations maintained by :mkfwd */
+/* static forward declarations maintained by mk-fwd */
 static void
 removeBackslashes( char* pzSrc );
 
@@ -399,7 +399,8 @@ scanXmlEntry( char const* pzName, tOptionValue* pRes )
         return pzName;
     }
 
-    while (isalpha( (int)*++pzScan ))  nameLen++;
+    pzScan++;
+    while (ISNAMECHAR( (int)*pzScan ))  { pzScan++; nameLen++; }
     if (nameLen > 64)
         return NULL;
     valu.valType = OPARG_TYPE_STRING;
@@ -664,6 +665,7 @@ optionLoadNested(char const* pzTxt, char const* pzName, size_t nameLen)
         else switch (*pzTxt) {
         case NUL: goto scan_done;
         case '<': pzTxt = scanXmlEntry( pzTxt, pRes );
+                  if (pzTxt == NULL) goto woops;
                   if (*pzTxt == ',') pzTxt++;     break;
         case '#': pzTxt = strchr( pzTxt, '\n' );  break;
         default:  goto woops;
